@@ -1,13 +1,12 @@
-/*
- * iconmenu.cc
- * Copyleft 2002 Frank Hale
- * frankhale@yahoo.com
- * http://sapphire.sourceforge.net/
+/* 
+ * frankhale@gmail.com
+ * http://frankhale.org
+ *
+ * This code is released under the GPL license www.gnu.org
  */
- 
 #include "aewm.hh"
 
-IconMenu::IconMenu() : GenericMenu()
+IconMenu::IconMenu(Display * dpy) : GenericMenu(dpy)
 {
 	updateMenu();
 	addToMenuList(this);
@@ -24,7 +23,7 @@ void IconMenu::handleButtonReleaseEvent(XButtonEvent *e)
 			{
 				switch(	curr->function )
 				{
-					case UNICONIFY:
+					case SHOW:
 						curr->client->unhide();
 						hideAllVisibleSubmenus();
 					break;
@@ -42,13 +41,47 @@ void IconMenu::addThisClient(Client *c)
 		BaseMenuItem *item = new BaseMenuItem();
 
 		item->client = c;
-		item->name=c->getClientIconName(); // name showing on menu.
-		item->function=UNICONIFY;
+		
+		if(c->getClientIconName() == NULL)
+		{
+			item->name = "untitled";
+		}else
+		{
+			item->name = c->getClientIconName();
+		}
+		
+		item->function=SHOW;
 	
 		insert(item);
 	}
 }
 
+void IconMenu::updateClientName(Client *c)
+{
+	list<BaseMenuItem*> menuItemList = getMenuItemList();
+	list<BaseMenuItem*>::iterator mit;
+	
+	for(mit = menuItemList.begin(); mit != menuItemList.end(); mit++)
+	{
+		if(*mit)
+		{
+			if((*mit)->client == c) 
+			{
+				if(c->getClientIconName() == NULL)
+				{
+					(*mit)->name = "Untitled";
+				}
+				else
+				{
+					(*mit)->name = c->getClientIconName();
+				}
+				
+				updateMenu();
+			}
+		}
+	}
+}
+
 void IconMenu::removeClientFromIconMenu(Client *c)
 {
 	list<BaseMenuItem*> menuItemList = getMenuItemList();
