@@ -1,13 +1,12 @@
-/*
- * windowmenu.cc
- * Copyleft 2002 Frank Hale
- * frankhale@yahoo.com
- * http://sapphire.sourceforge.net/
+/* 
+ * frankhale@gmail.com
+ * http://frankhale.org
+ *
+ * This code is released under the GPL license www.gnu.org
  */
- 
 #include "aewm.hh"
 
-WindowMenu::WindowMenu() : GenericMenu()
+WindowMenu::WindowMenu(Display * dpy) : GenericMenu(dpy)
 {
 	updateWindowMenu();
 }
